<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Empleados Model
 *
 * @property \Cake\ORM\Association\BelongsToMany $Users
 *
 * @method \App\Model\Entity\Empleado get($primaryKey, $options = [])
 * @method \App\Model\Entity\Empleado newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Empleado[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Empleado|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Empleado patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Empleado[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Empleado findOrCreate($search, callable $callback = null, $options = [])
 */
class EmpleadosTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->table('empleados');
        $this->displayField('cedula');
        $this->primaryKey('id');

        $this->belongsToMany('Users', [
            'foreignKey' => 'empleado_id',
            'targetForeignKey' => 'user_id',
            'joinTable' => 'users_empleados'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id');

        $validator
            ->allowEmpty('nombre');

        $validator
            ->allowEmpty('apellido');

        $validator
            ->integer('modalidad')
            ->allowEmpty('modalidad');

        $validator
            ->allowEmpty('fechaingreso');

        $validator
            ->integer('usistema')
            ->allowEmpty('usistema');

        $validator
            ->allowEmpty('telefono1');

        $validator
            ->allowEmpty('telefono2');

        $validator
            ->allowEmpty('telefono3');

        $validator
            ->allowEmpty('domicilio');

        $validator
            ->allowEmpty('nrodomi');

        $validator
            ->allowEmpty('dominum');

        $validator
            ->integer('edad')
            ->allowEmpty('edad');

        $validator
            ->integer('sexo')
            ->allowEmpty('sexo');

        $validator
            ->integer('estadocivil')
            ->allowEmpty('estadocivil');

        $validator
            ->allowEmpty('profesion');

        $validator
            ->allowEmpty('sena');

        $validator
            ->integer('esteempleado')
            ->allowEmpty('esteempleado');

        $validator
            ->numeric('sueldo')
            ->allowEmpty('sueldo');

        $validator
            ->numeric('horaxdia')
            ->allowEmpty('horaxdia');

        $validator
            ->numeric('horaextra')
            ->allowEmpty('horaextra');

        $validator
            ->numeric('fercosto')
            ->allowEmpty('fercosto');

        $validator
            ->integer('comitipo')
            ->allowEmpty('comitipo');

        $validator
            ->integer('prectipo')
            ->allowEmpty('prectipo');

        $validator
            ->integer('ventacont')
            ->allowEmpty('ventacont');

        $validator
            ->integer('ventacred')
            ->allowEmpty('ventacred');

        $validator
            ->integer('cobrador')
            ->allowEmpty('cobrador');

        $validator
            ->allowEmpty('observacion');

        $validator
            ->integer('moneda')
            ->allowEmpty('moneda');

        $validator
            ->numeric('comivcont')
            ->allowEmpty('comivcont');

        $validator
            ->numeric('comivcred')
            ->allowEmpty('comivcred');

        $validator
            ->allowEmpty('cedula');

        $validator
            ->allowEmpty('ruc');

        $validator
            ->allowEmpty('cargo');

        return $validator;
    }
}
