<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Ventas Model
 *
 * @method \App\Model\Entity\Venta get($primaryKey, $options = [])
 * @method \App\Model\Entity\Venta newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Venta[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Venta|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Venta|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Venta patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Venta[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Venta findOrCreate($search, callable $callback = null, $options = [])
 */
class VentasTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('ventas');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Empleados', [
            'foreignKey' => 'vendedors'
        ]);

    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 10)
            ->allowEmpty('fecha');

        $validator
            ->scalar('cedula')
            ->maxLength('cedula', 100)
            ->allowEmpty('cedula');

        $validator
            ->scalar('cliente')
            ->allowEmpty('cliente');

        $validator
            ->scalar('chasis')
            ->maxLength('chasis', 150)
            ->allowEmpty('chasis');

        $validator
            ->scalar('detalle')
            ->maxLength('detalle', 250)
            ->allowEmpty('detalle');

        $validator
            ->scalar('moneda')
            ->allowEmpty('moneda');

        $validator
            ->numeric('total')
            ->allowEmpty('total');

        $validator
            ->numeric('entregaminima')
            ->allowEmpty('entregaminima');

        $validator
            ->numeric('entregado')
            ->allowEmpty('entregado');

        $validator
            ->scalar('vendedor')
            ->allowEmpty('vendedor');

        $validator
            ->scalar('formadepago')
            ->allowEmpty('formadepago');

        $validator
            ->integer('cantidadcuota')
            ->allowEmpty('cantidadcuota');

        $validator
            ->numeric('saldo')
            ->allowEmpty('saldo');

        $validator
            ->numeric('comisionguaranies')
            ->allowEmpty('comisionguaranies');

        $validator
            ->numeric('comisiondolares')
            ->allowEmpty('comisiondolares');

        $validator
            ->scalar('monedacomision')
            ->allowEmpty('monedacomision');

        return $validator;
    }


     /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['vendedors'], 'Empleados'));

        return $rules;
    }

}
